@@ -1,4 +1,5 @@
 import argparse, os, re
+from audioop import add
 from datetime import date, datetime
 from tkinter import filedialog
 from typing import Dict, List, Tuple, Type
@@ -238,8 +239,28 @@ class Session:
     def __repr__(self) -> str:
         return self.name
 
+class Facility:
+    name: str
+    address1: str
+    address2: str
+    city: str
+    state: str
+    zip: str
+
+    def __init__(self, name, address1, address2, city, state, zip) -> None:
+        self.name = name
+        self.address1 = address1
+        self.address2 = address2
+        self.city = city
+        self.state = state
+        self.zip = zip
+
+    def __repr__(self) -> str:
+        return f"{self.name}"
+
 class Meet:
     name: str
+    facility: Facility
     start_date: date
     end_date: date
     sessions: List[Session]
@@ -412,6 +433,12 @@ def read(input):
 
     return meet
 
+def process_result(cursor, query):
+    cursor.execute(query)
+    result = cursor.fetchone()
+    columns = [column[0] for column in cursor.description]
+    return dict(zip(columns, result))
+
 def process_results(cursor, query):
     cursor.execute(query)
     results = cursor.fetchall()
@@ -460,8 +487,10 @@ def read_mdb(path):
     meet = Meet()
 
     # Meet
-    cursor.execute("SELECT Meet_name1 from Meet")
-    meet.name = cursor.fetchone()[0]
+    query = "SELECT Meet_name1, Meet_location, Meet_addr1, Meet_addr2, Meet_city, Meet_state from Meet"
+    result = process_result(cursor, query)
+    meet.name = result["Meet_name"].rstrip()
+    meet.facility = Facility(name=result["Meet_location"], address1=result["Meet_addr1"], city=result["Meet_city"], state=result["Meet_state"], zip=result["Meet_zip"])
     
     # Sessions
     query = "SELECT Sess_no, Sess_name, Sess_starttime, Sess_course FROM Session"
