@@ -1,5 +1,19 @@
 import json
 
+STROKES = {
+    "1": "Free",
+    "2": "Back",
+    "3": "Breast",
+    "4": "Fly",
+    "5": "IM",
+    "6": "Free Relay",
+    "7": "Medley Relay"
+}
+
+GENDERS_BG = {
+    "m": "Boys",
+    "f": "Girls"
+}
 
 class SDIFRecord:
 
@@ -129,6 +143,7 @@ class TeamIDRecord(SDIFRecord):
     
     code: str
     org_code: str
+    lsc_code: str
     team_code: str
     team_name: str
     team_name_abbr: str
@@ -144,7 +159,8 @@ class TeamIDRecord(SDIFRecord):
     encodings = {
         "code": (0,2),
         "org_code": (2,3),
-        "team_code": (11,17),
+        "lsc_code": (11,13),
+        "team_code": (13,17),
         "team_name": (17,47),
         "team_name_abbr": (47,63),
         "address_1": (63,85),
@@ -222,6 +238,7 @@ class IndividualEventRecord(SDIFRecord):
     org_code: str
     swimmer_name: str
     swimmer_id: str
+    "Incomplete swimmer USAS ID, omits the final 2 characters"
     attach_code: str
     citizen_code: str
     swimmer_birthdate: str
@@ -229,7 +246,7 @@ class IndividualEventRecord(SDIFRecord):
     swimmer_sex: str
     event_sex: str
     event_distance: str
-    stroke: str
+    event_stroke: str
     event_number: str
     event_lower_age: str
     event_upper_age: str
@@ -259,12 +276,12 @@ class IndividualEventRecord(SDIFRecord):
         "swimmer_id": (39,51),
         "attach_code": (51,52),
         "citizen_code": (52,55),
-        "swimmer_birtdate": (55,63),
+        "swimmer_birthdate": (55,63),
         "swimmer_age": (63,65),
         "swimmer_sex": (65,66),
         "event_sex": (66,67),
         "event_distance": (67,71),
-        "stroke": (71,72),
+        "event_stroke": (71,72),
         "event_number": (72,76),
         "event_lower_age": (76,78),
         "event_upper_age": (78,80),
@@ -291,6 +308,28 @@ class IndividualEventRecord(SDIFRecord):
     def __init__(self, data: str):
         super().__init__(data)
 
+    @property
+    def event_str(self):
+        gender = GENDERS_BG[self.event_sex.lower()]
+
+        lower_age = 0 if self.event_lower_age == "UN" else int(self.event_lower_age)
+        upper_age = 100 if self.event_upper_age == "OV" else int(self.event_upper_age)
+
+        if lower_age > 0 and upper_age < 100:
+            age_group = f"{lower_age}-{upper_age}"
+        elif lower_age <= 0 and upper_age < 100:
+            age_group = f"{upper_age} & Under"
+        elif lower_age > 0 and upper_age >= 100:
+            age_group = f"{lower_age} & Over"
+        else:
+            age_group = "Open"
+        
+        distance = self.event_distance
+
+        stroke = STROKES[self.event_stroke]
+
+        return f"{gender} {age_group} {distance} {stroke}"
+
 
 class IndividualAdministrativeRecord(SDIFRecord):
     """This record is used to identify the athlete and his/her
@@ -439,9 +478,31 @@ class RelayEventRecord(SDIFRecord):
     team_code: str
     num_swimmers: str
     event_sex: str
-    distance: str
-    stroke: str
+    event_distance: str
+    event_stroke: str
     event_number: str
+    event_lower_age: str
+    "Integer or \"UN\""
+    event_upper_age: str
+    "Integer or \"OV\""
+    total_age: str
+    date: str
+    seed_time: str
+    seed_course: str
+    prelim_time: str
+    prelim_course: str
+    swimoff_time: str
+    swimoff_course: str
+    final_time: str
+    final_course: str
+    prelim_heat: str
+    prelim_lane: str
+    final_heat: str
+    final_lane: str
+    prelim_rank: str
+    final_rank: str
+    points: str
+    time_class: str
 
     encodings = {
         "code": (0,2),
@@ -450,10 +511,11 @@ class RelayEventRecord(SDIFRecord):
         "team_code": (12,18),
         "num_swimmers": (18,20),
         "event_sex": (20,21),
-        "distace": (21,25),
-        "stroke": (25,26),
+        "event_distance": (21,25),
+        "event_stroke": (25,26),
         "event_number": (26,30),
-        "event_age": (30,34),
+        "event_lower_age": (30,32),
+        "event_upper_age": (32,34),
         "total_age": (34,37),
         "date": (37,45),
         "seed_time": (45,53),
@@ -473,6 +535,28 @@ class RelayEventRecord(SDIFRecord):
         "points": (95,99),
         "time_class": (99,101)
     }
+    
+    @property
+    def event_str(self):
+        gender = GENDERS_BG[self.event_sex.lower()]
+
+        lower_age = 0 if self.event_lower_age == "UN" else int(self.event_lower_age)
+        upper_age = 100 if self.event_upper_age == "OV" else int(self.event_upper_age)
+
+        if lower_age > 0 and upper_age < 100:
+            age_group = f"{lower_age}-{upper_age}"
+        elif lower_age <= 0 and upper_age < 100:
+            age_group = f"{upper_age} & Under"
+        elif lower_age > 0 and upper_age >= 100:
+            age_group = f"{lower_age} & Over"
+        else:
+            age_group = "Open"
+        
+        distance = self.event_distance
+
+        stroke = STROKES[self.event_stroke]
+
+        return f"{gender} {age_group} {distance} {stroke}"
 
     def __init__(self, data: str):
         super().__init__(data)
@@ -571,6 +655,7 @@ class SplitsRecord(SDIFRecord):
     time_9: str
     time_10: str
     swim_code: str
+    "Type of swim, ie. prelim, swim-off, final"
 
     encodings = {
         "code": (0,2),
