@@ -22,7 +22,7 @@ class Time:
                 raise ValueError(f"Invalid time string: {time}")
 
             minutes = m.group("minutes")
-            if minutes is None or minutes is "":
+            if minutes is None or minutes == "":
                 self.minutes = 0
             else:
                 self.minutes = int(minutes)
@@ -31,9 +31,9 @@ class Time:
             self.seconds = int(seconds)
 
             hundredths = m.group("hundredths")
-            if hundredths is None or hundredths is "":
+            if hundredths is None or hundredths == "":
                 self.hundredths = 0
-            elif len(hundredths) is 1:
+            elif len(hundredths) == 1:
                 self.hundredths = int(hundredths) * 10
             else:
                 self.hundredths = int(hundredths)
